;----------------------------------------------------------------------------
;       FILE: RISMCODE.ASM
;----------------------------------------------------------------------------
; This file contains initialization code and the Interrupt service routines.
;----------------------------------------------------------------------------
 IF BSO
	CSEG at RISM_INIT
 ELSE
	org RISM_INIT           ; RISM starts here!
 ENDIF

rism_start:
 IF C296
	ld int_pend1, #0	; Intel Errata, False NMI after RESET
 ENDIF

	di
	ld sp,#100H            ; Initialize stack pointer, must be WORD boundary
						   ; address, ie. EVEN address
;----------------------------------------------------------------------------
;   Place any custom initialization code here. 
;   Eg. Chip Selects for 196NP
;----------------------------------------------------------------------------
 IF DEBUG
 	lcall debug_port_init
 ENDIF
	lcall uart_init         ; Call to initialize UART, UART_ON_CHIP or OffChip!
	ldb WSR,#WORK_REGS

	clrb RISM_STAT          ; Initialize rism status register
 IF UART_ON_CHIP
    clrb    NMI_counter
 ENDIF
 IF  MODEL_24_BIT 
	ld templ,#EPREG   
	clr templ+2
	estb zero,[templ]      ; clear eport   
	ld templ,#EPMODE
	ldb rism_data,#0FH     ; make internal eport i/o
	estb rism_data,[templ] ; enable the eport
 ENDIF 
	ld templ,#rism_psw     ; value for rism and initial user value
	push templ              ; Set up psw for the monitor
	ld templ,#rism_wsr
	push templ
 IF MODEL_24_BIT
	ld user_pc,#LSW rism_pc
	ld user_pc+2,#MSW rism_pc
 ELSE
	ld user_pc,#rism_pc
 ENDIF    
	ld user_psw,#rism_psw  ; setup initial user PSW, WSR
	ld user_wsr,#rism_wsr
	andb RISM_STAT,#not( 1 SHL (BUSY mod 8) )
	popa                    ; load psw with rism value - LAST THING WE DO
	ljmp monitor_pause      ; Jump to Main Loop.
;----------------------------------------------------------------------------
; RISM Main
; After startup RISM loops here! 
;----------------------------------------------------------------------------
 IF BSO
	CSEG at ISR_CODE
 ELSE
	org ISR_CODE
 ENDIF

monitor_pause:              ; main loop for RISM 
 IF DEBUG
    ldb WSR,#WORK_REGS
    ld debug_reg,#0FFFFH
    djnzw debug_reg,$      ; wait 2 loops
    ld debug_reg,#0FFFFH
    djnzw debug_reg,$
    ldb debug_byte,DEBUG_PORT[0]
    xorb debug_byte,#01H             ; toggle debug port BIT0
    stb debug_byte,DEBUG_PORT[0]
 ENDIF
    br monitor_pause        ; wait for a command from the host
;----------------------------------------------------------------------------
; RISM interrupt service routine
; Control passes to this point when RISM gets a serial i/o interrupt
; from the host system.
;----------------------------------------------------------------------------
rism_isr:
	pusha
 IF MODEL_KC
 ELSE
	ldb WSR,#WORK_REGS     ; if not KB/KC/KD then window e0h to 1e0h or 3e0h 
 ENDIF

 IF DEBUG
    lcall ToggleLED1       ;   toggle debug port BIT1
 ENDIF
	orb RISM_STAT,#( 1 SHL (BUSY mod 8)  )

rism_exit:
	ljmp test_rx_uart

exit:
 IF DEBUG
	lcall ToggleLED2           ; toggle debug port BIT2
 ENDIF
	andb RISM_STAT,#not( 1 SHL (BUSY mod 8)  )
	popa
	ret
;----------------------------------------------------------------------------
 IF UART_ON_CHIP
;----------------------------------------------------------------------------
; NMI is connected to DTR line of PC.
; This routine is used while monitor is in user mode. Every byte sent to RISM       
; is followed by a toggle of the DTR line to force RISM to RECEIVE the byte.
; This is done so that if the USER program disabled the interrupts RISM can
; still talk to the HOST.
;----------------------------------------------------------------------------
NMI_interrupt_routine:
	pusha                   ; push all (PSW / INT_MASK / INT_MASK1 / WSR)
 IF MODEL_KC
 ELSE
	ldb WSR,#WORK_REGS     ; window e0h to 3e0h 
 ENDIF
	jbs RISM_STAT,BUSY,SERIAL_busy        ; is RISM receiving?
 IF MODEL_KC
	ldb WSR, #0		; In case User program changed WSR
				; popa will restore the original
	ldb nmi_temp,sp_stat           ; Check SP_STAT for RI
 ELSE
	ldb nmi_temp,sp_stat1F[0]      ; Check SP_STAT for RI
 ENDIF
	jbs nmi_temp,6,receive_ready   	; receiver ready
	jbs NMI_counter,4,NMI_restart 	; Used as a counter. If it gets to 
				    	; 10H then the target is reset
	incb NMI_counter                ; Count one failed NMI.

SERIAL_busy:
	popa                            ; if already in rism_isr return.
	ret
;----------------------------------------------------------------------------
; Reset Target
;----------------------------------------------------------------------------
NMI_restart:
	rst                     ; If counter gets to 10H then RESET occurs
	br $                    ; stay here until reset 
 ENDIF
;----------------------------------------------------------------------------
receive_ready:
	clrb NMI_counter        ; clear counter for NMI

 IF MODEL_KC
	stb WSR,tempb          ; save WSR
	stb zero,WSR           ; go to window 0
	lcall get_char          ; get character from receive buffer.
	stb tempb,WSR          ; restore WSR
 ELSE
	lcall get_char
 ENDIF
	clrb tempb              ; clear top for BR[templ]        
    jbs RISM_STAT,BLK_FLAG,block_copy             ; block maximum is 256
    jbs RISM_STAT,DLE_FLAG,force_load_data
    cmpb char,#1FH         ; check if byte is a command
	bh load_data            ; commands are <= 1FH
	ljmp process_command    ; jmp to command
;============================================================================
; RISM commands go here!
;============================================================================
 IF BSO
$include (rismtree.asm)
 ELSE
$rismtree.asm
 ENDIF
;----------------------------------------------------------------------------
; Place UART specific code in ISR_CODE segment so does not disappear if 
; REMAPPING hardware in use.
;----------------------------------------------------------------------------
 IF BSO
$include (rismuart.asm)
 ELSE
$rismuart.asm
 ENDIF

