;----------------------------------------------------------------------------
;       FILE: RISMMAIN.ASM
;----------------------------------------------------------------------------
; This file configures the remaining RISM files to the assembler you are 
; using, and includes those files into this 'MAIN' file for assembly.
;----------------------------------------------------------------------------
;       BSO:    Specifies whether you are using the BSO/Tasking assembler or
;               the IAR assembler. Set to 1 for BSO/Tasking assembler, 0 for 
;               the IAR assembler.
;----------------------------------------------------------------------------
BSO             SET 1           ; assembler switch
;----------------------------------------------------------------------------
;       DEBUG:  If you are having difficulty starting ChipView with your 
;               custom RISM there are several things you can do to help 
;               identify where the problem is:
;
;   If you are using ChipView-x96 do the following:
;
;        1. On the Options|Hardware Setup|Diagnostics dialog check the 
;           Log RISM channel item.
;
;        2. Open the Log window, and open a LOG file using the
;           Log|Open log file command.
;
;   If you are using ChipView-196 add the following command-line options:
;
;        -d1             this option monitors the serial-link between HOST
;                        and TARGET. All communications are sent to the LOG
;                        window within ChipView-196.
;
;        -sn<filename>   This option opens a file and routes all LOG
;                        window activity to the file specified.
;
;   This will generate a file that contains a list of all commands sent to 
;   the target and all data received by the host.You can use this 
;   information to see how far ChipView gets. If ChipView does not 
;   get past the first REPORT_STATUS and TRANSMIT then most likely there is 
;   something wrong with your RISM implementation.
;
;   Double check that ALL settings in the RISM files are correct. Check all 
;   items that deal with the UART and BAUD RATE, as well as any custom 
;   initialization that you added.
;
;   ****** Make sure that the CCR bytes are configured properly. If these
;          bytes are not correct your TARGET BOARD WILL NOT WORK at all.
;
;   If these steps do not work, set DEBUG to 1. By doing this, debug code 
;   is included throughout RISM so that you have some visual feedback.
;
;   In several locations throughout the RISM code, instructions have been
;   added to turn-on LED's. These are useful in finding out if RISM is actully
;   running correctly. The code uses LEDs connected to a location defined in 
;   RISMUART.DEF called DEBUG_PORT. Each bit signifies that RISM reached a 
;   certain location in the code:
;
;1. If BIT0 is blinking then RISM has reached monitor_pause and is waiting for
;   commands.
;   
;   If this bit is responding properly after power-up of the target,
;   then RISM has finished its initialization code and ChipView can be 
;   started(use the command-line options listed above). See step 2 below.
;
;   If this BIT is not responding properly after power-up of the target, 
;   possible causes are:
;
;               1. RISM startup code was not located at 2080H(0FF2080H).
;               2. Chip Configuration Bytes not right.
;
;
;2. If BIT1 is toggled then RISM entered the rism_isr interrupt routine. 
;   If BIT2 is toggled then RISM exited from the rism_isr routine successfully. 
;   If BIT3 toggles as well then RISM reached the TRANSMIT command routine.
;
;   NOTE:   These bits will toggle very quickly so keep a close eye on them or 
;           use a scope to watch the lines.
;
;   If these BITS do not act accordingly while ChipView is attempting
;   to connect, several causes could be:
;               
;               For On-Chip versions:
;
;               1.  the RI is not being received by the target.  
;               2.  the RI vector is not pointing to rism_isr.
;               3.  the NMI vector is not used and interrupts were not 
;                   turned on by RISM. Check the value of rism_psw, rism_wsr
;                   in RISMUART.DEF
;               4.  the NMI is used but the interrupt vector was not pointing
;                   to NMI_interrupt_routine.
;
;               For Off-Chip versions:
;
;               1.  the NMI is not being received by the target.  
;               2.  the NMI vector is not pointing to rism_isr.
;
;               For all versions:
;
;               1.  ChipView is using the wrong COM port.
;               2.  RISM TABLES not in overlapped memory(JUMP_TABLE version only).
;               3.  rism_isr/commands not in CODE area.
;               
;   If BIT1 - BIT3 respond correctly but ChipView still does not connect, look 
;   in the LOG file generated by ChipView. This file should contain the RISM 
;   commands that were sent to the TARGET as well as data received by the HOST. 
;   Check that the DATA received by the HOST makes sense. For example:
;                   
;                   If the HOST sends a 0 then issues the MONITOR_ESCAPE 
;                   command RISM should respond with MON_ESC_COUNT. Check
;                   to make sure the value corresponds with the value in 
;                   the RISM files.
;
;   If the last command sent was a SET_BAUD command then something is not
;   right with the values being used to set the baud rate. Check that the
;   correct crystal frequency is being used in RISMUART.DEF and the values
;   for the different baud rates are correct. The equation for calculating
;   the baud rates may be different depending on whether you use the on-chip
;   UART or some other memory-mapped UART.
;
;   It may be neccesary to MOVE/CHANGE this debug code for your target. The 
;   debug functions are listed in RISMUART.ASM at the end of the file.    
;   The code for toggling BIT0 is located within monitor_pause.
;----------------------------------------------------------------------------
DEBUG           SET 0           ; include debug code in RISM
;----------------------------------------------------------------------------
;   The file 'rismmain.def' contains target specific statements that need to
;   be altered to suit your target board. If you assemble this file without 
;   changing these settings, the RISM you will generate will be for a 196KC
;   target using the on-chip UART for communication to the HOST. It will also
;   use a binary search tree to process its commands, allowing you to place
;   RISM anywhere in your memory-map.
;----------------------------------------------------------------------------
IF BSO
$include (rismmain.def)
ELSE
$rismmain.def
ENDIF
;----------------------------------------------------------------------------
;//////////////////////DO NOT EDIT THIS SECTION//////////////////////////////
;----------------------------------------------------------------------------
VERSION_ID      equ     0022            ; version #     decimal value
RISMREV_ID      equ     0200            ; revision # and sub-revision #
MON_ESC_COUNT   equ     0006            ; 6 new V2.1 sub commands that are
                                        ; 100% compatible with RISM V1.0
RISM            SET 1                   ; used to Identify building of RISM
                                        ; to RISMDATA.ASM.
;----------------------------------------------------------------------------
;///////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
;       The following statements include the remaining RISM components.
; 
;       You must also alter the following files:
;   
;       rismuart.def:   This file contains settings for 'rism_psw', 
;                       'rism_wsr', and the interrupt vectors. Values 
;                       for your targets UART must be altered according to 
;                       your target board setup.
;
;       rismuart.asm:   This file contains code to receive data, transmit 
;                       data, change BAUD rates, and initialization code 
;                       specific to the UART on your target board.
;
;       rismdata.asm:   This file contains the RISM data registers. This file 
;                       is also included in a file that must be assembled and 
;                       linked with your user program to reserve space for 
;                       RISM components. See 'cvrism.asm' for details.
;
;       rismtabl.asm:   This file contains the RISM jump table, baud values, 
;                       and monitor escape table. This file is used only if 
;                       you have JUMP_TABLE set to 1. The baud values need 
;                       to be customized if you are using an off-chip UART. 
;                       The values for the RAM_MAP_TABLE need to be altered
;                       to reflect your targets memory map. If you set 
;                       JUMP_TABLE to 0, then these tables are not used. 
;                       In this case you will need to modify 'rismtree.asm'.
;                       There are two sets of values to be changed in this 
;                       file. The SET_BAUD command loads rism_data with baud 
;                       rate values. These values need to be changed according
;                       to the UART and FREQUNCY your target board is using.
;                       Also the values in the MONITOR_ESCAPE command need to
;                       be adjusted. There is a section describing the size and 
;                       location of RAM blocks. These values should be changed
;                       to reflect your targets memory map. More entries can 
;                       be added if RAM is located in more than one area of 
;                       your memory map. 
;----------------------------------------------------------------------------
IF BSO
$include (rismuart.def)         
$include (rismsfrs.equ)          
ELSE
$rismuart.def                   
$rismsfrs.equ                    
ENDIF
;----------------------------------------------------------------------------
;       ATTRIBUTES:     This value describes certain features to ChipView.
;                       
;                       A 1 indicates the item is active
;                       
;                                24-bit model
;                                |256-byte Block-Copy Command Active
;                                ||RI Active
;                                |||DTR Active
;                                ||||DTR causes RESET
;                                |||||UART_ON_CHIP
;                                ||||||RTS/CTS Active
;                                |||||||
;                       XXXXXXXXXXXXXXXX
;                   MSB                  LSB    
;                                            
;----------------------------------------------------------------------------
ATTRIBUTES equ ((MODEL_24_BIT SHL 6)+(BLK_CMD_ACTIVE SHL 5)+(RI_ACTIVE SHL 4)+(DTR_ACTIVE SHL 3)+(DTR_RESET SHL 2)+(UART_ON_CHIP SHL 1)+RTS_CTS)
;----------------------------------------------------------------------------
IF BSO
;----------------------------------------------------------------------------
IF JUMP_TABLE
$include (rismtabl.asm)         ; Contains RISM Command Table, MON_ESC table
ENDIF                           ; BAUD VALUE table, and RAM_MAP_TABLE.
$include (rismdata.asm)         ; Reserved DATA locations for RISM.
$include (rismcode.asm)         ; initialization, ISR parts of RISM.
;----------------------------------------------------------------------------
ELSE
;----------------------------------------------------------------------------
IF JUMP_TABLE
$rismtabl.asm                   ; Contains RISM Command Table, MON_ESC table
ENDIF                           ; BAUD VALUE table, and RAM_MAP_TABLE.
$rismdata.asm                   ; Reserved DATA locations for RISM.
$rismcode.asm                   ; initialization, ISR parts of RISM.
;----------------------------------------------------------------------------
ENDIF
;----------------------------------------------------------------------------
	end
