;----------------------------------------------------------------------------
;       FILE:RISMTABL.ASM
;----------------------------------------------------------------------------
; This file contains the RISM command TABLE, BAUD rate value table, and the        
; monitor escape command table. It is only included as part of RISM if the
; JUMP_TABLE variable is set to 1. Otherwise this file is ignored. 
;----------------------------------------------------------------------------
;       RAM_MAP_TABLE_LOCATION:     This value immediately follows the last 
;                                   sub command in the monitor_esc_table.
;                                   This is an optional table that
;                                   contains a list of entries describing the
;                                   location and size of RAM areas to 
;                                   ChipView. If you do not wish to use 
;                                   this RAM MAP description table set the 
;                                   value to 0H.
;----------------------------------------------------------------------------
RAM_MAP_TABLE_LOCATION  equ MON_ESC_COUNT+2      ; index to RAM table
;----------------------------------------------------------------------------
; The Baud Rate Capability value identifies which baud rates your target is 
; capable of producing. If you want ChipView to change baud rates, then 
; the rates that it will change to are listed in this mask.
;----------------------------------------------------------------------------
BAUD_RATE_CAPAB equ     00FFH           ; Bit descriptions: 0 - 1200
					;                   1 - 2400
					;                   2 - 4800
					;                   3 - 9600
					;                   4 - 19200
					;                   5 - 38400
					;                   6 - 57600
					;                   7 - 115200
;----------------------------------------------------------------------------
 IF BSO
	CSEG at TABLES_BASE
 ELSE
	org TABLES_BASE         
 ENDIF
;----------------------------------------------------------------------------
; The values in this table are used to set the BAUD RATE for the UART in use.
; See rismuart.def for the definitions of BAUD_RATE_xxxxxx.
;----------------------------------------------------------------------------
baud_val:
	dcw     BAUD_RATE_1200
	dcw     BAUD_RATE_2400
	dcw     BAUD_RATE_4800
	dcw     BAUD_RATE_9600
	dcw     BAUD_RATE_19200
	dcw     BAUD_RATE_38400
	dcw     BAUD_RATE_57600
	dcw     BAUD_RATE_115200
;----------------------------------------------------------------------------
;//////////////////////DO NOT EDIT THIS SECTION//////////////////////////////
;----------------------------------------------------------------------------
; RISM COMMAND TABLE
;----------------------------------------------------------------------------
 IF MODEL_24_BIT
command_table:
	dcl     (SET_DLE_FLAG     )             ; 00
	dcl     (exit             )             ; 01
	dcl     (TRANSMIT         )             ; 02
	dcl     (exit             )             ; 03
	dcl     (READ_BYTE        )             ; 04
	dcl     (READ_WORD        )             ; 05
	dcl     (READ_DOUBLE      )             ; 06
	dcl     (WRITE_BYTE       )             ; 07
	dcl     (WRITE_WORD       )             ; 08
	dcl     (WRITE_DOUBLE     )             ; 09
	dcl     (LOAD_ADDRESS     )             ; 0A
	dcl     (INDIRECT_ADDRESS )             ; 0B
	dcl     (READ_PSW         )             ; 0C
	dcl     (WRITE_PSW        )             ; 0D
	dcl     (READ_SP          )             ; 0E
	dcl     (WRITE_SP         )             ; 0F
	dcl     (READ_PC          )             ; 10
	dcl     (WRITE_PC         )             ; 11
	dcl     (START_USER       )             ; 12
	dcl     (STOP_USER        )             ; 13
	dcl     (REPORT_STATUS    )             ; 14
	dcl     (MONITOR_ESCAPE   )             ; 15
	dcl     (READ_WSR         )             ; 16
	dcl     (WRITE_WSR        )             ; 17
	dcl     (SET_BAUD         )             ; 18
	dcl     (READ_WORD_TRANSMIT)            ; 19
    dcl     (SET_BLK_FLAG      )            ; 1A
	dcl     (exit             )             ; 1B
	dcl     (exit             )             ; 1C
	dcl     (exit             )             ; 1D
	dcl     (exit             )             ; 1E
	dcl     (exit             )             ; 1F
 ELSE
command_table:
	dcw     (SET_DLE_FLAG     )             ; 00
	dcw     (exit             )             ; 01
	dcw     (TRANSMIT         )             ; 02
	dcw     (exit             )             ; 03
	dcw     (READ_BYTE        )             ; 04
	dcw     (READ_WORD        )             ; 05
	dcw     (READ_DOUBLE      )             ; 06
	dcw     (WRITE_BYTE       )             ; 07
	dcw     (WRITE_WORD       )             ; 08
	dcw     (WRITE_DOUBLE     )             ; 09
	dcw     (LOAD_ADDRESS     )             ; 0A
	dcw     (INDIRECT_ADDRESS )             ; 0B
	dcw     (READ_PSW         )             ; 0C
	dcw     (WRITE_PSW        )             ; 0D
	dcw     (READ_SP          )             ; 0E
	dcw     (WRITE_SP         )             ; 0F
	dcw     (READ_PC          )             ; 10
	dcw     (WRITE_PC         )             ; 11
	dcw     (START_USER       )             ; 12
	dcw     (STOP_USER        )             ; 13
	dcw     (REPORT_STATUS    )             ; 14
	dcw     (MONITOR_ESCAPE   )             ; 15
	dcw     (READ_WSR         )             ; 16
	dcw     (WRITE_WSR        )             ; 17
	dcw     (SET_BAUD         )             ; 18
	dcw     (READ_WORD_TRANSMIT)            ; 19
    dcw     (SET_BLK_FLAG      )            ; 1A
	dcw     (exit             )             ; 1B
	dcw     (exit             )             ; 1C
	dcw     (exit             )             ; 1D
	dcw     (exit             )             ; 1E
	dcw     (exit             )             ; 1F
 ENDIF

monitor_esc_table:
 IF MODEL_24_BIT
	dcw     lsw  MON_ESC_COUNT              ; 00
	dcw     lsw  0                          ; 01
	dcw     lsw  DEVICE_ID                  ; 02
	dcw     lsw  VERSION_ID                 ; 03
	dcw     lsw  BAUD_RATE_CAPAB            ; 04
    dcw     lsw  ATTRIBUTES                 ; 05
    dcw     lsw  RAM_MAP_TABLE_LOCATION     ; 06
	dcw     lsw  RISMREV_ID                 ; 07
 ELSE
	dcw     MON_ESC_COUNT                   ; 00
	dcw     0                               ; 01
	dcw     DEVICE_ID                       ; 02
	dcw     VERSION_ID                      ; 03
	dcw     BAUD_RATE_CAPAB                 ; 04
    dcw     ATTRIBUTES                      ; 05
    dcw     RAM_MAP_TABLE_LOCATION          ; 06
  	dcw     RISMREV_ID                      ; 07
 ENDIF
;----------------------------------------------------------------------------
;///////////////////////DO NOT MOVE THIS SECTION/////////////////////////////
;----------------------------------------------------------------------------
;   NOTE:       This table must immediately follow the monitor_esc_table.
;----------------------------------------------------------------------------
;       ram_map_table:          the first value in this table is the number
;                               of entries that the table has. Each entry
;                               consists of 3 or 6 words depending on the
;                               model you are using.
;
;                               Each entry will look like the following:
;                                       
;                               16-bit:     dcw START_ADDR
;                                           dcw LENGTH
;                                           dcw DECODE_MASK
;
;                               24-bit:     dcl START_ADDR
;                                           dcl LENGTH
;                                           dcl DECODE_MASK
;
;                               NOTE: For 24-bit models these values are longs.
; 
;                               Where START_ADDR is the address where
;                               the RAM block starts.
;   
;                               LENGTH is the size of the RAM block.
;
;                               DECODE_MASK is the description of the address
;                               lines used to decode the RAM block. Specify a 
;                               1 for each bit used, and a 0 for each bit NOT
;                               used to decode the RAM block. 
;                               
;                               If you have more than one block of RAM 
;                               place more entries immediately following the
;                               previous one and set the number of entries
;                               accordingly.     
;----------------------------------------------------------------------------
;       NUM_RAM_ENTRIES:            number of entries in the RAM_MAP_TABLE
;                                   that describe RAM blocks in your target
;                                   board.
;----------------------------------------------------------------------------
NUM_RAM_ENTRIES         equ 1       ;  number of entries in RAM_MAP_TABLE  
;----------------------------------------------------------------------------
ram_map_table:
    dcw     NUM_RAM_ENTRIES                 ; number of entries in table
 IF MODEL_24_BIT
    dcl     04000H                          ; start address of RAM block
    dcl     02000H                          ; RAM length
    dcl     01FFFH                          ; address decoding MASK.
    ; place more entries here if needed
 ELSE
    dcw     4000H                           ; start address of RAM location
    dcw     2000H                           ; RAM length
    dcw     1FFFH                           ; Mask of address bits decoded 
    ; place more entries here if needed
 ENDIF
;----------------------------------------------------------------------------
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
