;----------------------------------------------------------------------------
;       FILE: RISMTREE.ASM
;----------------------------------------------------------------------------
; This file contains the RISM commands as well as the code to select a 
; command. It is organized as a binary-search tree. This tree method requires
; NO tables in the DATA space. If you are using the BINARY TREE version of 
; RISM you must alter the values for the BAUD register in the SET_BAUD 
; command as well as the RAM TABLE entries in the MONITOR_ESCAPE command.
;----------------------------------------------------------------------------   
; RISM Commands
;----------------------------------------------------------------------------
force_load_data:
	andb RISM_STAT,#not( 1 SHL (DLE_FLAG mod 8) )
;----------------------------------------------------------------------------
load_data:
	shll rism_data,#8      ; make room for new byte
	ldb rism_data,char    ; fall through to exit1
;----------------------------------------------------------------------------
exit1:
	ljmp rism_exit
;----------------------------------------------------------------------------
block_copy:
 IF  MODEL_24_BIT
	estb char,[rism_addr]+
 ELSE  
	stb char,[rism_addr]+
 ENDIF
    decb rism_data                      ; maximum is 255 bytes at a time.
    jne end_block_copy
    andb RISM_STAT,#not(1 SHL (BLK_FLAG mod 8))    ; CLR BLK_FLAG

end_block_copy:
    ljmp rism_exit    
;----------------------------------------------------------------------------
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
 IF JUMP_TABLE
 ELSE
below02:
	cmpb char,#01H
	je exit1                ; do command #01H
				; do command #00H
 ENDIF
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
SET_DLE_FLAG:                   ; COMMAND 0
	orb RISM_STAT,#( 1 SHL (DLE_FLAG mod 8)  )
	ljmp rism_exit
;----------------------------------------------------------------------------
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
 IF JUMP_TABLE
 ELSE
below04:        
	cmpb char,#02H
	jh exit1                ; do command #03H
	jne below02
				; do command #02H
 ENDIF
;///////////////////////////////////////////////////////////////////////////////
;-------------------------------------------------------------------------------
TRANSMIT:                       ; COMMAND 2
 IF MODEL_KC
	stb WSR,tempb
	stb zero,WSR
	lcall put_char
	stb tempb,WSR
	shrl rism_data,#8
	inc rism_addr
 ELSE
	lcall put_char
	shrl rism_data,#8
	inc rism_addr
 IF MODEL_24_BIT     
	addc rism_addr+2,zero
 ENDIF
 ENDIF
 IF DEBUG
    lcall ToggleLED3        ; toggle debug port BIT3
 ENDIF    
	ljmp rism_exit
;----------------------------------------------------------------------------
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
 IF JUMP_TABLE
 ELSE
below08:
	cmpb char,#04H
	jh above04
	jne below04
				; do command #04H       
 ENDIF
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
READ_BYTE:                      ; COMMAND 4
 IF  MODEL_24_BIT
 IF  C296
	cmpb rism_addr+2, ZERO_REG
	jne read_byte_e
	
	cmp rism_addr, #06H		;	is it ACC_04
	jne read_byte_e

	ldb rism_data, ACC04
	ljmp rism_exit

read_byte_e:
 ENDIF
	eldb rism_data,[rism_addr]
 ELSE
	ldb rism_data,[rism_addr]
 ENDIF
	ljmp rism_exit
;----------------------------------------------------------------------------
READ_WORD:                      ; COMMAND 5
 IF  MODEL_24_BIT
 IF  C296
	cmpb rism_addr+2, ZERO_REG
	jne read_word_e

	cmp rism_addr, #06H			; is it ACC4
	jne read_word_ACC0

	ldb rism_data, ACC04
	ljmp rism_exit

read_word_ACC0:
	cmp rism_addr, #0CH			; is it ACC0
	jne read_word_ACC2

	ld rism_data, ACC00			
	ljmp rism_exit

read_word_ACC2:
	cmp rism_addr, #0EH			; is it ACC2
	jne read_word_e

	ld rism_data, ACC02
	ljmp rism_exit

read_word_e:
 ENDIF
	eld rism_data,[rism_addr]
 ELSE
	ld rism_data,[rism_addr]
 ENDIF
	ljmp rism_exit
;----------------------------------------------------------------------------
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
 IF JUMP_TABLE
 ELSE
above04:
	cmpb char,#06H
	jh WRITE_BYTE           ; do command #07H
	jne READ_WORD           ; do command #05H
				; do command #06H
 ENDIF
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
READ_DOUBLE:                    ; COMMAND 6
 IF  MODEL_24_BIT
	eld rism_data,[rism_addr]
	eld rism_data+2,2[rism_addr]
 ELSE
	ld rism_data,[rism_addr]
	ld rism_data+2,2[rism_addr]
 ENDIF
	ljmp rism_exit
;----------------------------------------------------------------------------
WRITE_BYTE:                     ; COMMAND 7
 IF  MODEL_24_BIT
 IF  C296
	cmpb rism_addr+2, ZERO_REG
	jne write_byte_e

	cmp rism_addr, #06H
	jne write_byte_e

	stb rism_data, ACC04
	add rism_addr, #1H
	ljmp rism_exit

write_byte_e:
 ENDIF
	estb rism_data,[rism_addr]+
 ELSE
	stb rism_data,[rism_addr]+
 ENDIF
	ljmp rism_exit
;----------------------------------------------------------------------------
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
 IF JUMP_TABLE
 ELSE
below10:
	cmpb char,#08H
	jh above08
	jne below08
				; do command #08H       
 ENDIF
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
WRITE_WORD:                     ; COMMAND 8
 IF  MODEL_24_BIT 
 IF  C296
	cmpb rism_addr+2, ZERO_REG
	jne write_word_e

	cmp rism_addr, #0CH			; is it ACC00
	jne write_word_ACC2

	st rism_data, ACC00
	add rism_addr, #2H
	ljmp rism_exit

write_word_ACC2:
	cmp rism_addr, #0EH			; is it ACC02
	jne write_word_e

	st rism_data, ACC02
	add rism_addr, #2H
	ljmp rism_exit

write_word_e:
 ENDIF
	est rism_data,[rism_addr]+
 ELSE
	st rism_data,[rism_addr]+
 ENDIF
	ljmp rism_exit
;----------------------------------------------------------------------------
WRITE_DOUBLE:                   ; COMMAND 9
 IF  MODEL_24_BIT
	est rism_data,[rism_addr]+
	est rism_data+2,[rism_addr]+
 ELSE
	st rism_data,[rism_addr]+
	st rism_data+2,[rism_addr]+
 ENDIF
	ljmp rism_exit
;----------------------------------------------------------------------------
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
 IF JUMP_TABLE
 ELSE
below0C:
	cmpb char,#0AH
	jh INDIRECT_ADDRESS     ; do command #0BH
	jne WRITE_DOUBLE        ; do command #09H
				; do command #0AH
 ENDIF
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
LOAD_ADDRESS:                   ; COMMAND 0A
	ld rism_addr,rism_data 
 IF MODEL_24_BIT     
	ld rism_addr+2,rism_data+2
 ENDIF
	ljmp rism_exit
;----------------------------------------------------------------------------     
INDIRECT_ADDRESS:               ; COMMAND 0B
 IF  MODEL_24_BIT
	eld templ,[rism_addr]
	eld rism_addr+2,2[rism_addr]
	ld rism_addr,templ
 ELSE
	ld rism_addr,[rism_addr]
 ENDIF
	ljmp rism_exit
;----------------------------------------------------------------------------     
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
 IF JUMP_TABLE
 ELSE
above08:
	cmpb char,#0CH
	jh above0C
	jne below0C
				; do command #0C
 ENDIF
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
READ_PSW:                       ; COMMAND 0C
	jbs RISM_STAT,RUN_FLAG,rpsw_running
	ld rism_data,user_psw  ; user is not running
	ljmp rism_exit

rpsw_running:
	ld rism_data,2[sp]      ; user is running
	ljmp rism_exit
;----------------------------------------------------------------------------
WRITE_PSW:                      ; COMMAND 0D
 IF DTR_ACTIVE                 ; interrupts enabled always if DTR not connected
 ELSE
	or rism_data,#0200H    ; user is not running
 ENDIF
	ld user_psw,rism_data
	ljmp rism_exit
;----------------------------------------------------------------------------
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
 IF JUMP_TABLE
 ELSE
above0C:
	cmpb char,#0EH
	jh WRITE_SP             ; do command #0FH
	jne WRITE_PSW           ; do command #0DH
				; do command #0EH
 ENDIF
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
READ_SP:                        ; COMMAND 0E
 IF  MODEL_24_BIT
	add rism_data,sp,#8
 ELSE
	add rism_data,sp,#6
 ENDIF
	ljmp rism_exit
;----------------------------------------------------------------------------
WRITE_SP:                       ; COMMAND 0F
	st rism_data,sp
	br set_rism_idle
;----------------------------------------------------------------------------
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
process_command:
;----------------------------------------------------------------------------
 IF JUMP_TABLE
;----------------------------------------------------------------------------
 IF MODEL_24_BIT
	shl templ,#2           ; convert "char" to dword index
	ldbze templ+2,# MSW($)    ; load upper word of jump address
    eld templ,(command_table-0FF0000H)[templ]     ; sub 0ff0000H so good index
 ELSE
	shl templ,#1           ; convert "char" to word index
	ld templ,(command_table)[templ]
 ENDIF
	br [templ]
;----------------------------------------------------------------------------
 ELSE
;----------------------------------------------------------------------------
	cmpb char,#10H     ; start at middle of binary tree
	bh above10
	jne below10
				; do command #10H
;----------------------------------------------------------------------------
 ENDIF                           
;----------------------------------------------------------------------------
READ_PC:                        ; COMMAND 10
	bbs RISM_STAT,RUN_FLAG,rpc_running
	ld rism_data,user_pc   ; If user code is not running
 IF  MODEL_24_BIT
	ld rism_data+2,user_pc+2
 ENDIF
	ljmp rism_exit

rpc_running:
	ld rism_data,4[sp]     ; If user code is running
 IF  MODEL_24_BIT
	ld rism_data+2,6[sp]
 ENDIF
	ljmp rism_exit
;----------------------------------------------------------------------------
WRITE_PC:                       ; COMMAND 11
	st rism_data,user_pc  
 IF  MODEL_24_BIT
	st rism_data+2,user_pc+2
 ENDIF
	ljmp rism_exit
;----------------------------------------------------------------------------
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
 IF JUMP_TABLE
 ELSE
below14:
	cmpb char,#12H
	jh STOP_USER            ; do command #13H
	jne WRITE_PC            ; do command #11H
				; do command #12H
 ENDIF
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
START_USER:                     ; COMMAND 12
	orb RISM_STAT,#( 1 SHL (RUN_FLAG mod 8)  )
	andb RISM_STAT,#not( 1 SHL (TRAP_FLAG mod 8) )
	add sp,#6               ; reset sp to overwrite RISM pc & psw, WSR
	ldb WSR,#WORK_REGS
 IF  MODEL_24_BIT
	add sp,#2               ; 24-bit has extra word on stack
	push user_pc+2
 ENDIF 
	push user_pc            ; with user pc &

 IF DTR_ACTIVE              ; interrupts enabled always if DTR not connected
 ELSE
    IF UART_ON_CHIP
        or user_psw,#0200H      ; and using On-Chip UART
    ENDIF
 ENDIF

	push user_psw           ; user psw values
	push user_wsr

	lcall update_host_start             ; update running signal to host
	andb RISM_STAT,#not( 1 SHL (BUSY mod 8) )     
    ; rism not busy while user is running
	ljmp exit
;----------------------------------------------------------------------------
break:
	pusha                   ; push all (PSW / INT_MASK / INT_MASK1 / WSR)
	ldb WSR,#WORK_REGS     ; window e0h to 1e0h 
	orb RISM_STAT,#( 1 SHL (TRAP_FLAG mod 8)  )
;----------------------------------------------------------------------------
STOP_USER:                                                      ; COMMAND 13
	andb zero,RISM_STAT,#(1 SHL (RUN_FLAG mod 8) )    ; are there bits set ?
	je exit_rism_idle               ; if zero then already stopped
	pop user_wsr                    ; remove users wsr from stack
	pop user_psw                    ; remove users psw & pc from stack
	pop user_pc                     ; and save
 IF  MODEL_24_BIT
	pop user_pc+2
 ENDIF

set_rism_idle:
 IF  MODEL_24_BIT
	push # MSW(monitor_pause)         ; save high word of pc
	push # LSW(monitor_pause)             ; the new program counter & psw
 ELSE
	push # monitor_pause             ; the new program counter & psw
 ENDIF 
	push #rism_psw
	push #rism_wsr
	andb RISM_STAT,#not(1 SHL (RUN_FLAG mod 8))    ; CLR  RUN_FLAG
	lcall update_host_stop          ; update running signal to host.

exit_rism_idle:
	andb RISM_STAT,#not( 1 SHL (BUSY mod 8) )     
    ; clear BUSY on way out.
	ljmp exit
;----------------------------------------------------------------------------
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
 IF JUMP_TABLE
 ELSE
below18:
	cmpb char,#14H
	bh above14
	bne below14
				; do command #14H       
 ENDIF
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
REPORT_STATUS:                  ; COMMMAND 14
stopped   equ 0
running   equ 1
trapped   equ 2
     
	ldbze rism_data,RISM_STAT
	andb rism_data,#not(1 SHL (BUSY mod 8)) 

exit2:
	ljmp rism_exit
;----------------------------------------------------------------------------
MONITOR_ESCAPE:                 ; COMMAND 15
	cmp rism_data,#01
	bne monitor_exec

    rst                     ; Execute a reset instruction
    br $                    ; and loop until reset takes effect

monitor_exec:
;----------------------------------------------------------------------------
 IF JUMP_TABLE
;----------------------------------------------------------------------------
	shll rism_data,#1
 IF MODEL_24_BIT
	clr rism_data+2
	eld rism_data,monitor_esc_table[rism_data]
 ELSE
	ld rism_data,monitor_esc_table[rism_data]
 ENDIF
	ljmp rism_exit                  
;----------------------------------------------------------------------------
 ELSE     
;----------------------------------------------------------------------------
;   These variables are duplicated in 'rismtabl.asm' and are referenced here 
;   only if JUMP_TABLE is set to 0. 
;----------------------------------------------------------------------------
;   RAM_MAP_TABLE_LOCATION:     This value immediately follows the last 
;                               sub command in the monitor_esc_table.
;                               This is an optional table that
;                               contains a list of entries describing the
;                               location and size of RAM areas to 
;                               ChipView. If you do not wish to use 
;                               this RAM MAP description table set the 
;                               value to 0H.
;----------------------------------------------------------------------------
RAM_MAP_TABLE_LOCATION  equ MON_ESC_COUNT+2      ; index to RAM table
;----------------------------------------------------------------------------
	cmp rism_data,#00H
	jh mon_above0
    ld rism_data,#MON_ESC_COUNT    ; do MON_ESC of 0
    ljmp rism_exit

mon_above0:
    cmp rism_data,#02H
	jh mon_above2
    ld rism_data,#DEVICE_ID        ; device ID
	ljmp rism_exit

mon_above2:
    cmp rism_data,#03H
    jh mon_above3
    ld rism_data,#VERSION_ID       ; version ID
    ljmp rism_exit

mon_above3:
	cmp rism_data,#04H
	jh  mon_above4
	ld rism_data,#BAUD_RATE_CAPAB             
	ljmp rism_exit

mon_above4:
	cmp rism_data,#05H
	jh  mon_above5
	ld rism_data,#ATTRIBUTES
	ljmp rism_exit

mon_above5:
	cmp rism_data,#06H
	jh  mon_above6
	ld rism_data,#RAM_MAP_TABLE_LOCATION
	ljmp rism_exit
;----------------------------------------------------------------------------
;   USER:   Place RAM table entries here 
;           If you need to add more entries change NUM_RAM_ENTRIES
;           and copy the marked sections below for each new entry.
;----------------------------------------------------------------------------
;   NUM_RAM_ENTRIES:            number of entries in the RAM_MAP_TABLE
;                               that describe RAM blocks in your target
;                               board.
;----------------------------------------------------------------------------
NUM_RAM_ENTRIES         equ 1       ;  number of entries in RAM_MAP_TABLE  
;----------------------------------------------------------------------------
mon_above6:
    cmp rism_data,#07H
    jh mon_above7
    ld rism_data,#NUM_RAM_ENTRIES  ; number of entries in RAM table
    ljmp rism_exit
;----------------------------------------------------------------------------
;   USER:   Repeat this section for each RAM block description. Change 
;           the value being compared to the next highest and the value 
;           being loaded into rism_data to the appropriate value.
;----------------------------------------------------------------------------
 IF MODEL_24_BIT
mon_above7:
    cmp rism_data,#08H
    jh mon_above8
    ld rism_data,#4000H            ; start addr of RAM block - lo
    ljmp rism_exit

mon_above8:
    cmp rism_data,#09H
    jh mon_above9
    ld rism_data,#0000H            ; start addr of RAM block - hi
    ljmp rism_exit

mon_above9:
    cmp rism_data,#0AH
    jh mon_aboveA
    ld rism_data,#2000H            ; length of RAM block - lo
    ljmp rism_exit

mon_aboveA:
    cmp rism_data,#0BH
    jh mon_aboveB
    ld rism_data,#0000H            ; length of RAM block - hi
    ljmp rism_exit

mon_aboveB:
    cmp rism_data,#0CH
    jh mon_aboveC
    ld rism_data,#1FFFH            ; Address-bit MASK - lo
    ljmp rism_exit

mon_aboveC:
    cmp rism_data,#0DH
    jh mon_above_exit
    ld rism_data,#0000H            ; Address-bit MASK - hi
    ljmp rism_exit

 ELSE
mon_above7:
    cmp rism_data,#08H
    jh mon_above8
    ld rism_data,#6000H            ; start addr of RAM block
    ljmp rism_exit

mon_above8:
    cmp rism_data,#09H
    jh mon_above9
    ld rism_data,#2000H            ; length of RAM block 
    ljmp rism_exit

mon_above9:
    cmp rism_data,#0AH
    jh mon_above_exit
    ld rism_data,#1FFFH            ; Address-bit MASK 
    ljmp rism_exit
 ENDIF
;----------------------------------------------------------------------------
mon_above_exit:
    ljmp rism_exit
;----------------------------------------------------------------------------
 ENDIF           ; END MONITOR_ESCAPE
;----------------------------------------------------------------------------
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
 IF JUMP_TABLE
 ELSE
above14:
	cmpb char,#16H
	jh WRITE_WSR            ; do command #17H
	bne MONITOR_ESCAPE      ; do command #15H
				; do command #16H
 ENDIF
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
READ_WSR:                       ; COMMAND 16
	jbs RISM_STAT,RUN_FLAG,rwsr_running
	ld rism_data,user_wsr  ; user is not running
	ljmp rism_exit

rwsr_running:
	ld rism_data,[sp]       ; user is running
	ljmp rism_exit
;----------------------------------------------------------------------------
WRITE_WSR:                      ; COMMAND 17
	or rism_data,#(rism_wsr AND 0FF00H)  ; re-set RI in INT_MASK1
    ld user_wsr,rism_data
	ljmp rism_exit
;----------------------------------------------------------------------------
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
 IF JUMP_TABLE
 ELSE
above10:
	cmpb char,#18H
	bh above18              ; highest is 1AH
	bne below18
				; do command #18H       
 ENDIF
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
SET_BAUD:                        ; COMMAND 18
;----------------------------------------------------------------------------
    cmp rism_data,#7       ; if above 7 then must be baud_value already
    jh set_baud_cont        ; so go set it! For compatibility with RISM V1
;----------------------------------------------------------------------------
 IF JUMP_TABLE
;----------------------------------------------------------------------------
	shll rism_data,#1              ; NOTE! ALL BAUD RATES MUST BE PRESENT
 IF MODEL_24_BIT                          ; as this is an index into table.
	clr rism_data+2
	eld rism_data,baud_val[rism_data]
 ELSE
	ld rism_data,baud_val[rism_data]
 ENDIF
;----------------------------------------------------------------------------
 ELSE
;----------------------------------------------------------------------------
;   USER:   The Baud Rate Capability value identifies which baud rates your 
;           target is capable of producing. If you want ChipView to 
;           change baud rates, then the rates that it will change to are 
;           listed in this mask. The BAUD_RATE_CAPAB variable is duplicated 
;           in 'rismtabl.asm' and is referenced here only if JUMP_TABLE is 
;           set to 0. 
;----------------------------------------------------------------------------
BAUD_RATE_CAPAB equ     00FFH           ; Bit descriptions: 0 - 1200
					;                   1 - 2400
					;                   2 - 4800
					;                   3 - 9600
					;                   4 - 19200
					;                   5 - 38400
					;                   6 - 57600
					;                   7 - 115200
;----------------------------------------------------------------------------
	cmp rism_data,#3H                          
	bh set_above3
	bne set_below3
	ld rism_data,#BAUD_RATE_9600           ; 9600
	sjmp set_baud_cont

set_below3:
	cmp rism_data,#1H
	bh set_2
	bne set_0
	ld rism_data,#BAUD_RATE_2400           ; 2400
	sjmp set_baud_cont

set_2:
	ld rism_data,#BAUD_RATE_4800           ; 4800
	sjmp set_baud_cont

set_0:
	ld rism_data,#BAUD_RATE_1200           ; 1200 
	sjmp set_baud_cont

set_above3:
	cmp rism_data,#5H
	bh set_above5
	bne set_4
	ld rism_data,#BAUD_RATE_38400          ; 38400
	sjmp set_baud_cont

set_4:
	ld rism_data,#BAUD_RATE_19200          ; 19200
	sjmp set_baud_cont

set_above5:
	cmp rism_data,#6H
	bh set_7
	ld rism_data,#BAUD_RATE_57600          ; 57600
	sjmp set_baud_cont

set_7:  
	ld rism_data,#BAUD_RATE_115200         ; 115200
;----------------------------------------------------------------------------
 ENDIF
;----------------------------------------------------------------------------
set_baud_cont:
	lcall set_baud_rate
	ljmp rism_exit
;----------------------------------------------------------------------------
READ_WORD_TRANSMIT:                 ; COMMAND 19H
 IF MODEL_24_BIT
 IF C296
	cmpb rism_addr+2, ZERO_REG
	jne read_word_transmit_e

	cmp rism_addr, #06H				; is it ACC04
	jne read_word_transmit_ACC00

	ldb rism_data, ACC04
	ljmp TRANSMIT

read_word_transmit_ACC00:
	cmp rism_addr, #0CH				; is it ACC00
	jne read_word_transmit_ACC02

	ld rism_data, ACC00
	ljmp TRANSMIT

read_word_transmit_ACC02:

	cmp rism_addr, #0EH				; is it ACC02
	jne read_word_transmit_e

	ld rism_data, ACC02
	ljmp TRANSMIT

read_word_transmit_e:
 ENDIF
	eld rism_data,[rism_addr]
 ELSE
	ld rism_data,[rism_addr]
 ENDIF
	ljmp TRANSMIT
;----------------------------------------------------------------------------
;////////////////////////DO NOT REMOVE THIS SECTION//////////////////////////
 IF JUMP_TABLE
 ELSE
above18:
	cmpb char,#1AH
	bh exit1                ; commands above 1A do not exist          
	bne READ_WORD_TRANSMIT
					; do command #1AH       
 ENDIF
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
BLK_CMD_ACTIVE      SET 1       ; Set to 1 if Block Copy command is present.
;----------------------------------------------------------------------------
SET_BLK_FLAG:                       ; COMMAND 1AH
    orb RISM_STAT,#( 1 SHL( BLK_FLAG mod 8) )  ; set block copy flag
    ljmp rism_exit
