;----------------------------------------------------------------------------
;       FILE: RISMUART.ASM
;----------------------------------------------------------------------------
;   This file contains code specific to the UART your target board is using.
;
;   If you are using the on-chip UART, then edit the section marked with an 
;   on-chip heading, otherwise edit the sections that are marked with an 
;   off-chip heading. NOTE that there are sections for the KB, KC, and KD as well
;   as sections for the other models. Be sure to edit the correct section.
;----------------------------------------------------------------------------
;////////////////////////////////////////////////////////////////////////////
;----------------------------------------------------------------------------
 IF UART_ON_CHIP
;----------------------------------------------------------------------------
 IF MODEL_KC             ; ***on-chip UART for models KB, KC, and KD
			            ; sets up 8N1, 9600, RI set in INT_MASK1
;----------------------------------------------------------------------------
uart_init:
	ldb ioc1,#20H                              
	ldb int_mask1,#02H
	ldb baud,#(BAUD_REG AND 00FFH)            ; 67H
	ldb baud,#(BAUD_REG AND 0FF00H) SHR 8     ; 80H
	ldb sp_con,#9H
	ldb zero,sp_stat   ; clear status register by reading
	ret
;----------------------------------------------------------------------------
 ELSE                    ; ***on-chip UART for all models except KB, KC, and KD
			            ; setup Rx, Tx pins as SFR's, 8N1, 9600, 
;----------------------------------------------------------------------------
uart_init:
	ldb WSR,#1Fh           ; window sfr's
	ldb P2REG,#00100010B
	andb P2IO,#11011110B           ;P2.5 OUTPUT, RXD IN, TXD OUT
	orb P2IO,#02H                ;SET RXD TO INPUT
	orb  P2SSEL,#03H               ; turn Rxd,Txd pins into SFRs
    ldb int_mask,#40H      ; enable INT6   
	ldb sp_con,#9              
	ld  sp_baud,#BAUD_REG       
	ldb zero,sp_stat      ; clear status register by reading
	ret 
;----------------------------------------------------------------------------
 ENDIF
;----------------------------------------------------------------------------
 ELSE                    ; ***off-chip UART
			            ; This code is for an 82510 UART
;----------------------------------------------------------------------------
uart_init:
 IF MODEL_KC
	jbc ios1,5,$              ; wait for timer overflow
	jbc ios1,5,$              ; twice 
	stb zero,2000H             ; release UART reset(on INTEL EVAL BOARD )
	jbc ios1,5,$              ; ....till UART is ready
 ELSE
    stb zero,2000H             ; release UART reset(on INTEL EVAL BOARD )
    ldb WSR,#1FH               ; window SFR's
    ldb t1_control,#11000011b  ; start timer 1 - divide by 8, up-counter 
    ld timer_1,#1              ; delay 65535 ticks

wait0:  
    cmp timer_1,zero
    bne wait0

    ld timer_1,#1              ; delay 65535 ticks

wait1:  
    cmp timer_1,zero
    bne wait1

    ld timer_1,#1              ; delay 65535 ticks

wait3: 
    cmp timer_1,zero
    bne wait3
    clrb t1_control
    clrb WSR
 ENDIF
    ldb tempb,#80H             ; set dlab bit in line_config reg...
	stb tempb,line_config[0]   ; so that baud_a reg's are accessable
	ldb tempb,#3CH             ; set baud rate to 9600
	stb tempb,baud_a_lo[0]
	stb zero,baud_a_hi[0]
	ldb tempb,#03H             ; set up uart line config reg for no...
	stb tempb,line_config[0]   ; par, 1 stop, 8bit, and txd_rxd access
	ldb tempb,#60H             ; switch to bank3
	stb tempb,general_int[0]
	ldb tempb,#50H             ; select baud rate gen. a for both...
	stb tempb,clock_confg[0]   ; rx and tx clock source
	ldb tempb,#7FH             ; select OUT1 mode on pin 12
	stb tempb,io_mode[0]
	stb zero,general_int[0]    ; switch to bank0
	ldb tempb,#01H             ; enable receive fifo interrupt...
	stb tempb,gener_enabl[0]   ; of the uart
	ret
;----------------------------------------------------------------------------
 ENDIF   
;----------------------------------------------------------------------------
; Test if really receive interrupt. 
;----------------------------------------------------------------------------
test_rx_uart:
 IF UART_ON_CHIP         ; ***on-chip UART

 IF MODEL_KC
	stb WSR, char
	stb zero, WSR
	ldb tempb,sp_stat                  ; non-windowed
	stb char, WSR
 ELSE
	ldb tempb,sp_stat1F[0]   			; Receive Interrupt, therefore we are ready!
 ENDIF
	bbs tempb,6,receive_ready         ; Jump to Receive if really RI
	ljmp exit                           ; may be serviced by NMI too!

 ELSE                    ; ***off-chip UART
						; Test UART interrupt register for receive 
						; interrupt bit.
						; This code is for an 82510 UART
	ldb char,general_int[0]            ; read uart interrupt status
	xorb char,#00000100B               ; test for receive fifo interrupt
	je rx_ready
	ldb char,#01H                      ; enable only recieve fifo interrupt.
	stb char,gener_enabl[0]            ; of the uart, mask all others
	ljmp exit
rx_ready:
	ljmp receive_ready                  ; jump back to exit if not receive.
;----------------------------------------------------------------------------
 ENDIF
;----------------------------------------------------------------------------
; Get character from receive buffer
;----------------------------------------------------------------------------
get_char:
 IF UART_ON_CHIP                     ; ***on-chip UART
	ldb char,sbuf_rx               ; Receive byte 
 ELSE                                ; ***off-chip UART
						            ; This code is for an 82510 UART
	ldb char,txd_rxd[0]            ; Receive byte
 ENDIF
	ret 
;----------------------------------------------------------------------------
; Put character to transmit buffer
;----------------------------------------------------------------------------
put_char:
 IF UART_ON_CHIP                             ; ***on-chip UART
	stb rism_data,sbuf_tx
 ELSE                                        ; ***off-chip UART
							                ; This code is for an 82510 UART
	stb rism_data,txd_rxd[0] 
 ENDIF   
	ret
;----------------------------------------------------------------------------
; Set Baud Rate                         ; value is in rism_data register
;----------------------------------------------------------------------------
set_baud_rate:
 IF UART_ON_CHIP                         ; ***on-chip UART
	orb rism_data+1,#80H               ; using XTAL1 to clock
 IF  MODEL_24_BIT
	est rism_data,sp_baud1F[0]
 ELSE
 IF MODEL_KC
	stb rism_data,baud             ; KB, KC, KD have byte-wide BAUD 
	stb rism_data+1,baud           ; register                
 ELSE
	st rism_data,sp_baud1F[0]
 ENDIF
 ENDIF
 ELSE            ; ***OffChip UART
				; This code is for an 82510 UART
				; Be sure to change the values in the SET_BAUD command
				; if you set JUMP_TABLE to 0, or the values in the 
				; BAUD_VAL table if you set JUMP_TABLE to 1.
	ldb tempb,#80H             ; set dlab bit in line_config reg...
	stb tempb,line_config[0]   ; so that baud_a reg's are accessable
	stb rism_data,baud_a_lo[0]
	stb rism_data+1,baud_a_hi[0]
	ldb tempb,#03H             ; clear lab bit in line_config reg...
	stb tempb,line_config[0]   ; so that baud_a reg's are accessable
 ENDIF
	ret
;----------------------------------------------------------------------------
update_host_start:
	push WSR
 IF UART_ON_CHIP
 IF MODEL_KC
 ELSE
	ldb WSR,#1FH    ; window sfr's
 ENDIF   
	andb RING_INDICATOR,#not(1 SHL (RING_BIT mod 8))      
			; update running signal to host
 ELSE
	ldb char,#(1 SHL (RING_BIT mod 8))
	stb char,RING_INDICATOR[0]         ; update running signal to host
 ENDIF
	pop WSR
	ret
;----------------------------------------------------------------------------
update_host_stop:
	push WSR
 IF UART_ON_CHIP
 IF MODEL_KC
 ELSE
	ldb WSR,#1FH           ; window sfr's if not KB, KC, KD 
 ENDIF   
	orb RING_INDICATOR,#(1 SHL (RING_BIT mod 8))      
				; update running signal to host
 ELSE
	ldb char,#0
	stb char,RING_INDICATOR[0]     ; update running signal to host
 ENDIF
	pop WSR
	ret
;----------------------------------------------------------------------------
 IF DEBUG

debug_port_init:
 IF MODEL_24_BIT
    stb zero,P1IO[0]
 ENDIF
    stb zero,DEBUG_PORT[0]        ; DEBUG PORT init with 0

    ret

; WORK_REGS MUST be setup first, if not add ldb wsr, #WORK_REGS 
ToggleLED1:
    ldb debug_byte,DEBUG_PORT[0]
    xorb debug_byte,#02H             ; toggle BIT1
    stb debug_byte,DEBUG_PORT[0]
    ret

ToggleLED2:
    ldb debug_byte,DEBUG_PORT[0]
    xorb debug_byte,#04H             ; toggle BIT2
    stb debug_byte,DEBUG_PORT[0]    
    ret                                 

ToggleLED3:
    ldb debug_byte,DEBUG_PORT[0]
    xorb debug_byte,#08H             ; toggle BIT3
    stb debug_byte,DEBUG_PORT[0]    
    ret                                 

ToggleLED4:
    ldb debug_byte,DEBUG_PORT[0]
    xorb debug_byte,#010H            ; toggle BIT4
    stb debug_byte,DEBUG_PORT[0]    
    ret                                 

 ENDIF
;----------------------------------------------------------------------------
